@@ -1,23 +1,4 @@
 package Gtk2::CodeGen;
-#
-# Copyright (c) 2003 by the gtk2-perl team (see the file AUTHORS)
-#
-# This library is free software; you can redistribute it and/or
-# modify it under the terms of the GNU Library General Public
-# License as published by the Free Software Foundation; either
-# version 2 of the License, or (at your option) any later version.
-#
-# This library is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-# Library General Public License for more details.
-#
-# You should have received a copy of the GNU Library General Public
-# License along with this library; if not, write to the 
-# Free Software Foundation, Inc., 59 Temple Place - Suite 330, 
-# Boston, MA  02111-1307  USA.
-#
-# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/CodeGen.pm,v 1.7 2003/08/01 00:01:32 muppetman Exp $
 
 use strict;
 use warnings;
@@ -349,13 +330,7 @@ sub gen_enum_stuff {
 # define newSV$classname(val)	(gperl_convert_back_enum ($typemacro, val))
 #endif /* $typemacro */
 ";
-	push @typemap, "$classname	T_$typemacro";
-	push @input, "T_$typemacro
-	\$var = Sv$classname(\$arg);
-";
-	push @output, "T_$typemacro
-	\$arg = newSV$classname(\$var);
-";
+	push @typemap, "$classname	T_GPERL_GENERIC_WRAPPER";
 	push @boot, "#ifdef $typemacro
 gperl_register_fundamental ($typemacro, \"$package\");
 #endif /* $typemacro */"
@@ -370,13 +345,7 @@ sub gen_flags_stuff {
 # define newSV$classname(val)	(gperl_convert_back_flags ($typemacro, val))
 #endif /* $typemacro */
 ";
-	push @typemap, "$classname	T_$typemacro";
-	push @input, "T_$typemacro
-	\$var = Sv$classname(\$arg);
-";
-	push @output, "T_$typemacro
-	\$arg = newSV$classname(\$var);
-";
+	push @typemap, "$classname	T_GPERL_GENERIC_WRAPPER";
 	push @boot, "#ifdef $typemacro
 gperl_register_fundamental ($typemacro, \"$package\");
 #endif /* $typemacro */"
@@ -401,25 +370,11 @@ sub gen_boxed_stuff {
 # define newSV$classname\_own_ornull(val)	((val) ? newSV$classname\_own(val) : &PL_sv_undef)
 #endif /* $typemacro */
 ";
-	push @typemap, "$classname *	T_$typemacro";
-	push @typemap, "$classname\_ornull *	T_$typemacro\_ORNULL";
-	push @typemap, "$classname\_own *	T_$typemacro\_OWN";
-	push @typemap, "$classname\_copy *	T_$typemacro\_COPY";
-	push @typemap, "$classname\_own_ornull *	T_$typemacro\_OWN_ORNULL";
-	push @input, "T_$typemacro
-	\$var = Sv$classname(\$arg);
-T_$typemacro\_ORNULL
-	\$var = Sv$classname\_ornull(\$arg);
-";
-	push @output, "T_$typemacro
-	\$arg = newSV$classname(\$var);
-T_$typemacro\_OWN
-	\$arg = newSV$classname\_own(\$var);
-T_$typemacro\_COPY
-	\$arg = newSV$classname\_copy(\$var);
-T_$typemacro\_OWN_ORNULL
-	\$arg = newSV$classname\_own_ornull(\$var);
-";
+	push @typemap, "$classname *	T_GPERL_GENERIC_WRAPPER";
+	push @typemap, "$classname\_ornull *	T_GPERL_GENERIC_WRAPPER";
+	push @typemap, "$classname\_own *	T_GPERL_GENERIC_WRAPPER";
+	push @typemap, "$classname\_copy *	T_GPERL_GENERIC_WRAPPER";
+	push @typemap, "$classname\_own_ornull *	T_GPERL_GENERIC_WRAPPER";
 	push @boot, "#ifdef $typemacro
 gperl_register_boxed ($typemacro, \"$package\", NULL);
 #endif /* $typemacro */"
@@ -442,18 +397,8 @@ sub gen_object_stuff {
 # define newSV$classname\_ornull(val)	(((val) == NULL) ? &PL_sv_undef : $get_wrapper)
 ";
 
-	push @typemap, "$classname *	T_$typemacro";
-	push @typemap, "$classname\_ornull *	T_$typemacro\_NULLOK";
-	push @input, "T_$typemacro
-	\$var = Sv$classname(\$arg);
-T_$typemacro\_NULLOK
-	\$var = Sv$classname\_ornull(\$arg);
-";
-	push @output, "T_$typemacro
-	\$arg = newSV$classname(\$var);
-T_$typemacro\_NULLOK
-	\$arg = newSV$classname\_ornull(\$var);
-";
+	push @typemap, "$classname *	T_GPERL_GENERIC_WRAPPER";
+	push @typemap, "$classname\_ornull *	T_GPERL_GENERIC_WRAPPER";
 	push @boot, "#ifdef $typemacro
 gperl_register_object ($typemacro, \"$package\");
 #endif /* $typemacro */";
@@ -464,16 +409,16 @@ gperl_register_object ($typemacro, \"$package\");
 		$header[$#header] .= "typedef $classname $classname\_noinc;
 #define newSV$classname\_noinc(val)	(gperl_new_object (G_OBJECT (val), TRUE))
 ";
-		push @typemap, "$classname\_noinc *	T_$typemacro\_NOINC";
-		$output[$#output] .= "T_$typemacro\_NOINC
-	\$arg = newSV$classname\_noinc(\$var);
-";
+		push @typemap, "$classname\_noinc *	T_GPERL_GENERIC_WRAPPER";
 	}
 
 	# close the header ifdef
 	$header[$#header] .= "#endif /* $typemacro */\n";
 }
 
+1;
+__END__
+
 =back
 
 =head1 BUGS
@@ -489,6 +434,23 @@ The code is ugly.
 
 muppet <scott at asofyet dot org>
 
-=cut
+=head1 COPYRIGHT
 
-1;
+Copyright (C) 2003 by the gtk2-perl team (see the file AUTHORS for the full
+list)
+
+This library is free software; you can redistribute it and/or modify it under
+the terms of the GNU Library General Public License as published by the Free
+Software Foundation; either version 2.1 of the License, or (at your option)
+any later version.
+
+This library is distributed in the hope that it will be useful, but WITHOUT
+ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+FOR A PARTICULAR PURPOSE.  See the GNU Library General Public License for
+more details.
+
+You should have received a copy of the GNU Library General Public License
+along with this library; if not, write to the Free Software Foundation, Inc.,
+59 Temple Place - Suite 330, Boston, MA  02111-1307  USA.
+
+=cut
