@@ -1,5 +1,22 @@
 #
-# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/Gtk2.pm,v 1.29 2003/08/29 03:17:08 muppetman Exp $
+# Copyright (C) 2003 by the gtk2-perl team (see the file AUTHORS for the full
+# list)
+# 
+# This library is free software; you can redistribute it and/or modify it under
+# the terms of the GNU Library General Public License as published by the Free
+# Software Foundation; either version 2.1 of the License, or (at your option)
+# any later version.
+# 
+# This library is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+# FOR A PARTICULAR PURPOSE.  See the GNU Library General Public License for
+# more details.
+# 
+# You should have received a copy of the GNU Library General Public License
+# along with this library; if not, write to the Free Software Foundation, Inc.,
+# 59 Temple Place - Suite 330, Boston, MA  02111-1307  USA.
+#
+# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/Gtk2.pm,v 1.39 2003/10/10 03:36:35 muppetman Exp $
 #
 
 package Gtk2;
@@ -14,7 +31,7 @@ use Glib;
 
 require DynaLoader;
 
-our $VERSION = '0.96';
+our $VERSION = '1.00';
 
 our @ISA = qw(DynaLoader);
 
@@ -28,7 +45,15 @@ sub import {
 # this is critical -- tell dynaloader to load the module so that its 
 # symbols are available to all other modules.  without this, nobody
 # else can use important functions like gtk2perl_new_object!
-sub dl_load_flags { 0x01 }
+# 
+# hrm.  win32 doesn't really use this, because we have to link the whole
+# thing at compile time to ensure all the symbols are defined.
+#
+# on darwin, at least with the particular 5.8.0 binary i'm using, perl
+# complains "Can't make loaded symbols global on this platform" when this
+# is set to 0x01, but goes on to work fine.  returning 0 here avoids the
+# warning and doesn't appear to break anything.
+sub dl_load_flags { $^O eq 'darwin' ? 0x00 : 0x01 }
 
 # now load the XS code.
 bootstrap Gtk2 $VERSION;
@@ -175,25 +200,28 @@ http://gtk2-perl.sourceforge.net
 
 =head1 SEE ALSO
 
-perl(1), Glib(3pm).
+L<perl>(1), L<Glib>(3pm).
 
-Gtk2::Gdk::Keysyms(3pm) contains a hash of key codes, culled from
+L<Gtk2::Gdk::Keysyms>(3pm) contains a hash of key codes, culled from
 gdk/gdkkeysyms.h
 
-Gtk2::api(3pm) describes how to map the C API into perl, and some of the
+L<Gtk2::api>(3pm) describes how to map the C API into perl, and some of the
 important differences in the perl bindings.
 
-Gtk2::Helper(3pm) contains stuff that makes writing Gtk2 programs
+L<Gtk2::Helper>(3pm) contains stuff that makes writing Gtk2 programs
 a little easier.
 
-Gtk2::SimpleList(3pm) makes the GtkListStore and GtkTreeModel a I<lot>
+L<Gtk2::SimpleList>(3pm) makes the GtkListStore and GtkTreeModel a I<lot>
 easier to use.
 
+L<Gtk2::Pango>(3pm) exports various little-used but important constants you
+may need to work with pango directly.
+
 Gtk2 also provides code to make it relatively painless to create perl
-wrappers for other GLib/Gtk-based libraries.  See Gtk2::CodeGen, 
-Glib::PkgConfig, and ExtUtils::Depends.  If you're writing bindings,
-you'll probably also be interested in Gtk2::devel, which is a supplement
-to Glib::devel and Glib::xsapi.  The Binding Howto, at
+wrappers for other GLib/Gtk-based libraries.  See L<Gtk2::CodeGen>,
+L<Glib::PkgConfig>, and L<ExtUtils::Depends>.  If you're writing bindings,
+you'll probably also be interested in L<Gtk2::devel>, which is a supplement
+to L<Glib::devel> and L<Glib::xsapi>.  The Binding Howto, at
 http://gtk2-perl.sourceforge.net/doc/binding_howto.pod.html, ties it all
 together.
 
