@@ -1,5 +1,26 @@
 #!/usr/bin/perl -w
 
+#
+# Copyright (C) 2003 by the gtk2-perl team (see the file AUTHORS for the full
+# list)
+# 
+# This library is free software; you can redistribute it and/or modify it under
+# the terms of the GNU Library General Public License as published by the Free
+# Software Foundation; either version 2.1 of the License, or (at your option)
+# any later version.
+# 
+# This library is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+# FOR A PARTICULAR PURPOSE.  See the GNU Library General Public License for
+# more details.
+# 
+# You should have received a copy of the GNU Library General Public License
+# along with this library; if not, write to the Free Software Foundation, Inc.,
+# 59 Temple Place - Suite 330, Boston, MA  02111-1307  USA.
+#
+# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/examples/simplelist.pl,v 1.7 2003/09/30 20:37:52 rwmcfa1 Exp $
+#
+
 use strict;
 use Data::Dumper;
 
@@ -79,6 +100,7 @@ foreach (
 		[ 'Delete', 'Delete the ~middle element from the list' ],
 		[ 'Empty', 'Delete all rows from the list with an empty array assignement' ],
 		[ 'Fill', 'Fill the list with data using an array assignment' ],
+		[ 'Many', 'Push and Unshift several data element onto the list' ],
 		[ 'Dump List', 'Dump list data to stdout' ],
 		[ 'Dump Sel', 'Dump index of selected item(s)' ],
 	)
@@ -219,6 +241,31 @@ sub btn_clicked
 				[4, 5, 6] ],
 		);
 	}
+	elsif( $op eq 'Many' )
+	{
+		# can't use shorthand on this b/c we're replacing the ref
+		# in the simple list's data.
+		push @{$slist->{data}}, (
+			[ 'one', 1, 1.1, 1, 'uno', undef, 'uno', 
+				[1, 2, 3] ],
+			[ 'two', 2, 2.2, 0, 'dos', undef, 'dos', 
+				[2, 3, 4] ],
+			[ 'three', 3, 3.3, 1, 'tres', undef, 'tres', 
+				[3, 4, 5] ],
+			[ 'four', 4, 4.4, 0, 'quatro', undef,  'quatro', 
+				[4, 5, 6] ],
+		);
+		unshift @{$slist->{data}}, (
+			[ 'one', 1, 1.1, 1, 'uno', undef, 'uno', 
+				[1, 2, 3] ],
+			[ 'two', 2, 2.2, 0, 'dos', undef, 'dos', 
+				[2, 3, 4] ],
+			[ 'three', 3, 3.3, 1, 'tres', undef, 'tres', 
+				[3, 4, 5] ],
+			[ 'four', 4, 4.4, 0, 'quatro', undef,  'quatro', 
+				[4, 5, 6] ],
+		);
+	}
 	elsif( $op eq 'Dump Sel' )
 	{
 		print "selected indices: "
